@@ -136,6 +136,7 @@ class ConstructHub(
         id: builtins.str,
         *,
         alarm_actions: AlarmActions,
+        backend_dashboard_name: typing.Optional[builtins.str] = None,
         dashboard_name: typing.Optional[builtins.str] = None,
         domain: typing.Optional["Domain"] = None,
         isolate_lambdas: typing.Optional[builtins.bool] = None,
@@ -144,6 +145,7 @@ class ConstructHub(
         :param scope: -
         :param id: -
         :param alarm_actions: (experimental) Actions to perform when alarms are set.
+        :param backend_dashboard_name: (experimental) The name of the CloudWatch dashboard that represents the health of backend systems.
         :param dashboard_name: (experimental) The name of the CloudWatch Dashboard created to observe this application. Must only contain alphanumerics, dash (-) and underscore (_). Default: "construct-hub"
         :param domain: (experimental) Connect the hub to a domain (requires a hosted zone and a certificate).
         :param isolate_lambdas: (experimental) Whether sensitive Lambda functions (which operate on un-trusted complex data, such as the transliterator, which operates with externally-sourced npm package tarballs) should run in network-isolated environments. This implies the creation of additonal resources, including: - A VPC with only isolated subnets. - VPC Endpoints (CodeArtifact, CodeArtifact API, S3) - A CodeArtifact Repository with an external connection to npmjs.com Default: true
@@ -152,6 +154,7 @@ class ConstructHub(
         '''
         props = ConstructHubProps(
             alarm_actions=alarm_actions,
+            backend_dashboard_name=backend_dashboard_name,
             dashboard_name=dashboard_name,
             domain=domain,
             isolate_lambdas=isolate_lambdas,
@@ -182,6 +185,7 @@ class ConstructHub(
     jsii_struct_bases=[],
     name_mapping={
         "alarm_actions": "alarmActions",
+        "backend_dashboard_name": "backendDashboardName",
         "dashboard_name": "dashboardName",
         "domain": "domain",
         "isolate_lambdas": "isolateLambdas",
@@ -192,6 +196,7 @@ class ConstructHubProps:
         self,
         *,
         alarm_actions: AlarmActions,
+        backend_dashboard_name: typing.Optional[builtins.str] = None,
         dashboard_name: typing.Optional[builtins.str] = None,
         domain: typing.Optional["Domain"] = None,
         isolate_lambdas: typing.Optional[builtins.bool] = None,
@@ -199,6 +204,7 @@ class ConstructHubProps:
         '''(experimental) Props for ``ConstructHub``.
 
         :param alarm_actions: (experimental) Actions to perform when alarms are set.
+        :param backend_dashboard_name: (experimental) The name of the CloudWatch dashboard that represents the health of backend systems.
         :param dashboard_name: (experimental) The name of the CloudWatch Dashboard created to observe this application. Must only contain alphanumerics, dash (-) and underscore (_). Default: "construct-hub"
         :param domain: (experimental) Connect the hub to a domain (requires a hosted zone and a certificate).
         :param isolate_lambdas: (experimental) Whether sensitive Lambda functions (which operate on un-trusted complex data, such as the transliterator, which operates with externally-sourced npm package tarballs) should run in network-isolated environments. This implies the creation of additonal resources, including: - A VPC with only isolated subnets. - VPC Endpoints (CodeArtifact, CodeArtifact API, S3) - A CodeArtifact Repository with an external connection to npmjs.com Default: true
@@ -212,6 +218,8 @@ class ConstructHubProps:
         self._values: typing.Dict[str, typing.Any] = {
             "alarm_actions": alarm_actions,
         }
+        if backend_dashboard_name is not None:
+            self._values["backend_dashboard_name"] = backend_dashboard_name
         if dashboard_name is not None:
             self._values["dashboard_name"] = dashboard_name
         if domain is not None:
@@ -229,6 +237,15 @@ class ConstructHubProps:
         assert result is not None, "Required property 'alarm_actions' is missing"
         return typing.cast(AlarmActions, result)
 
+    @builtins.property
+    def backend_dashboard_name(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The name of the CloudWatch dashboard that represents the health of backend systems.
+
+        :stability: experimental
+        '''
+        result = self._values.get("backend_dashboard_name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def dashboard_name(self) -> typing.Optional[builtins.str]:
         '''(experimental) The name of the CloudWatch Dashboard created to observe this application.
